{ config, pkgs, ... }:

{
  imports =
    [ 
      ../../base.nix
      ./hardware-configuration.nix
    ];

  networking.hostName = "redshirt"; 
  networking.networkmanager.enable = true;

  # Select internationalisation properties.
  i18n.defaultLocale = "en_US.UTF-8";
  console = {
    font = "Lat2-Terminus16";
   # keyMap = "no";
    useXkbConfig = true; # use xkbOptions in tty.
  };

  # Enable the X11 windowing system.
  services.xserver = {
    enable = true;
    windowManager = {
      qtile.enable = true;
    };
    # Enable touchpad support (enabled default in most desktopManager).
    libinput.enable = true;
  };
  

  # Configure keymap in X11
  services.xserver.layout = "no";

  fonts.fonts = with pkgs; [
    (nerdfonts.override { fonts = [ "FiraCode" "Hack" ]; })
  ];

  sound.enable = true;

  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    pulse.enable = true;
    jack.enable = true;
  };

  # TODO: Enable home-manager with config from ./home.nix instead of users.users
  users.users.felixalb = {
    extraGroups = [ "networkmanager" ]; 
    shell = pkgs.zsh;
  };

  environment.systemPackages = with pkgs; [
    zsh
    cifs-utils
  ];

  documentation.man.generateCaches = true;


  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "22.05"; # Did you read the comment?

}

